
bservices
=========

A server service library Based on the components of Openstack.

* **WSGI Server:** Handle the WSGI request.
* **TCP  Server:** Handle the TCP request.
* **Pool Server:** Handle the you-defined request.
* **Task Server:** Handle the task.

Usage
=====

See https://github.com/xgfone/bservices/blob/master/bservices/examples/example_server.py
